<?php

declare(strict_types=1);

namespace BitBag\SyliusBonusPointsPlugin\Twig\Extension;

use BitBag\SyliusBonusPointsPlugin\Resolver\BonusPointsResolverInterface;
use BitBag\SyliusBonusPointsPlugin\Resolver\CartBonusPointsAmountResolver;
use Sylius\Component\Core\Model\OrderInterface;
use Twig\Extension\AbstractExtension;
use Twig\TwigFunction;

class BonusPointsExtension extends AbstractExtension
{
    /** @var BonusPointsResolverInterface */
    private $bonusPointsResolver;
    /** @var CartBonusPointsAmountResolver */
    private $cartBonusPointsAmountResolver;

    public function __construct(
        BonusPointsResolverInterface $bonusPointsResolver,
        CartBonusPointsAmountResolver $cartBonusPointsAmountResolver
    ) {
        $this->bonusPointsResolver = $bonusPointsResolver;
        $this->cartBonusPointsAmountResolver = $cartBonusPointsAmountResolver;
    }

    public function getFunctions(): array
    {
        return [
            new TwigFunction('bitbag_active_bonus_points', [$this, 'getActiveBonusPoints']),
            new TwigFunction('bitbag_cart_bonus_points_amount', [$this, 'getCartBonusPointsAmount']),
        ];
    }

    public function getActiveBonusPoints(): int
    {
        return $this->bonusPointsResolver->resolveBonusPoints();
    }

    public function getCartBonusPointsAmount(OrderInterface $order): int
    {
        return $this->cartBonusPointsAmountResolver->resolveBonusPoints($order);
    }
}
